﻿using Dundas.BI;
using Dundas.BI.Data.DataRetrieval;
using Dundas.BI.Extensibility;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ServerEventsSample
{
    /// <summary>
    /// This class represents the extension package info for the Server Events. 
    /// </summary>
    public class ServerEventsExtensionPackageInfo : ExtensionPackageInfo2
    {

        /// <summary>Initializes a new instance of the <see cref="ServerEventsExtensionPackageInfo"/> class.</summary>
        /// <param name="extensionManifest">The extension manifest.</param>
        public ServerEventsExtensionPackageInfo(ExtensionManifest extensionManifest)
                    : base(extensionManifest)
        {
        }

        /// <summary>
        /// Called after the extension package is loaded during engine startup.
        /// </summary>
        public override void OnLoaded()
        {
            IEventHookService eventHookService =
                Engine.Current.GetService<IEventHookService>();

            // Hooks up event handler when a file system entry is created.
            eventHookService.CreatedFileSystemEntry += eventHookService_CreatedFileSystemEntry;
            
        }

        /// <summary>
        /// Handles the CreatedFileSystemEntry event of the eventHookService control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="ItemChangedEventArgs{Dundas.BI.FileSystem.FileSystemEntry}"/> instance containing the event data.</param>
        void eventHookService_CreatedFileSystemEntry(object sender, ItemChangedEventArgs<Dundas.BI.FileSystem.FileSystemEntry> e)
        {

            IDataRetrievalService dataRetrievalService =
                Engine.Current.GetService<IDataRetrievalService>();

            dataRetrievalService.ClearResultCache();
        }

    }
}
